__name__ = 'ritetag'
__description__ = 'RiteTag API client.'
__url__ = 'https://github.com/pavelhouzva/ritetag-api-python'
__version__ = '1.3.0'
__author__ = 'Pavel Houžva'
__email__ = 'pavel@ritekit.com'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2021 Pavel Houžva'


from enum import Enum


class HashtagPosition(Enum):
    auto = 'auto'
    end = 'end'

    def __str__(self):
        return '{0}'.format(self.value)


class AnimationType(Enum):
    none = 'none'
    rays = 'rays'
    glint = 'glint'
    circle = 'circle'

    def __str__(self):
        return '{0}'.format(self.value)


class FontList(Enum):
    ABeeZee = 'ABeeZee'
    Abel = 'Abel'
    Abhaya_Libre = 'Abhaya Libre'
    Abril_Fatface = 'Abril Fatface'
    Aclonica = 'Aclonica'
    Acme = 'Acme'
    Actor = 'Actor'
    Adamina = 'Adamina'
    Advent_Pro = 'Advent Pro'
    Aguafina_Script = 'Aguafina Script'
    Akronim = 'Akronim'
    Aladin = 'Aladin'
    Alata = 'Alata'
    Alatsi = 'Alatsi'
    Aldrich = 'Aldrich'
    Alef = 'Alef'
    Alegreya = 'Alegreya'
    Alegreya_SC = 'Alegreya SC'
    Alegreya_Sans = 'Alegreya Sans'
    Alegreya_Sans_SC = 'Alegreya Sans SC'
    Aleo = 'Aleo'
    Alex_Brush = 'Alex Brush'
    Alfa_Slab_One = 'Alfa Slab One'
    Alice = 'Alice'
    Alike = 'Alike'
    Alike_Angular = 'Alike Angular'
    Allan = 'Allan'
    Allerta = 'Allerta'
    Allerta_Stencil = 'Allerta Stencil'
    Allura = 'Allura'
    Almarai = 'Almarai'
    Almendra = 'Almendra'
    Almendra_Display = 'Almendra Display'
    Almendra_SC = 'Almendra SC'
    Amarante = 'Amarante'
    Amaranth = 'Amaranth'
    Amatic_SC = 'Amatic SC'
    Amethysta = 'Amethysta'
    Amiko = 'Amiko'
    Amiri = 'Amiri'
    Amita = 'Amita'
    Anaheim = 'Anaheim'
    Andada = 'Andada'
    Andika = 'Andika'
    Angkor = 'Angkor'
    Annie_Use_Your_Telescope = 'Annie Use Your Telescope'
    Anonymous_Pro = 'Anonymous Pro'
    Antic = 'Antic'
    Antic_Didone = 'Antic Didone'
    Antic_Slab = 'Antic Slab'
    Anton = 'Anton'
    Arapey = 'Arapey'
    Arbutus = 'Arbutus'
    Arbutus_Slab = 'Arbutus Slab'
    Architects_Daughter = 'Architects Daughter'
    Archivo = 'Archivo'
    Archivo_Black = 'Archivo Black'
    Archivo_Narrow = 'Archivo Narrow'
    Aref_Ruqaa = 'Aref Ruqaa'
    Arima_Madurai = 'Arima Madurai'
    Arimo = 'Arimo'
    Arizonia = 'Arizonia'
    Armata = 'Armata'
    Arsenal = 'Arsenal'
    Artifika = 'Artifika'
    Arvo = 'Arvo'
    Arya = 'Arya'
    Asap = 'Asap'
    Asap_Condensed = 'Asap Condensed'
    Asar = 'Asar'
    Asset = 'Asset'
    Assistant = 'Assistant'
    Astloch = 'Astloch'
    Asul = 'Asul'
    Athiti = 'Athiti'
    Atma = 'Atma'
    Atomic_Age = 'Atomic Age'
    Aubrey = 'Aubrey'
    Audiowide = 'Audiowide'
    Autour_One = 'Autour One'
    Average = 'Average'
    Average_Sans = 'Average Sans'
    Averia_Gruesa_Libre = 'Averia Gruesa Libre'
    Averia_Libre = 'Averia Libre'
    Averia_Sans_Libre = 'Averia Sans Libre'
    Averia_Serif_Libre = 'Averia Serif Libre'
    B612 = 'B612'
    B612_Mono = 'B612 Mono'
    Bad_Script = 'Bad Script'
    Bahiana = 'Bahiana'
    Bahianita = 'Bahianita'
    Bai_Jamjuree = 'Bai Jamjuree'
    Baloo_2 = 'Baloo 2'
    Baloo_Bhai_2 = 'Baloo Bhai 2'
    Baloo_Bhaina_2 = 'Baloo Bhaina 2'
    Baloo_Chettan_2 = 'Baloo Chettan 2'
    Baloo_Da_2 = 'Baloo Da 2'
    Baloo_Paaji_2 = 'Baloo Paaji 2'
    Baloo_Tamma_2 = 'Baloo Tamma 2'
    Baloo_Tammudu_2 = 'Baloo Tammudu 2'
    Baloo_Thambi_2 = 'Baloo Thambi 2'
    Balsamiq_Sans = 'Balsamiq Sans'
    Balthazar = 'Balthazar'
    Bangers = 'Bangers'
    Barlow = 'Barlow'
    Barlow_Condensed = 'Barlow Condensed'
    Barlow_Semi_Condensed = 'Barlow Semi Condensed'
    Barriecito = 'Barriecito'
    Barrio = 'Barrio'
    Basic = 'Basic'
    Baskervville = 'Baskervville'
    Battambang = 'Battambang'
    Baumans = 'Baumans'
    Bayon = 'Bayon'
    Be_Vietnam = 'Be Vietnam'
    Bebas_Neue = 'Bebas Neue'
    Belgrano = 'Belgrano'
    Bellefair = 'Bellefair'
    Belleza = 'Belleza'
    Bellota = 'Bellota'
    Bellota_Text = 'Bellota Text'
    BenchNine = 'BenchNine'
    Bentham = 'Bentham'
    Berkshire_Swash = 'Berkshire Swash'
    Beth_Ellen = 'Beth Ellen'
    Bevan = 'Bevan'
    Big_Shoulders_Display = 'Big Shoulders Display'
    Big_Shoulders_Text = 'Big Shoulders Text'
    Bigelow_Rules = 'Bigelow Rules'
    Bigshot_One = 'Bigshot One'
    Bilbo = 'Bilbo'
    Bilbo_Swash_Caps = 'Bilbo Swash Caps'
    BioRhyme = 'BioRhyme'
    BioRhyme_Expanded = 'BioRhyme Expanded'
    Biryani = 'Biryani'
    Bitter = 'Bitter'
    Black_And_White_Picture = 'Black And White Picture'
    Black_Han_Sans = 'Black Han Sans'
    Black_Ops_One = 'Black Ops One'
    Blinker = 'Blinker'
    Bokor = 'Bokor'
    Bonbon = 'Bonbon'
    Boogaloo = 'Boogaloo'
    Bowlby_One = 'Bowlby One'
    Bowlby_One_SC = 'Bowlby One SC'
    Brawler = 'Brawler'
    Bree_Serif = 'Bree Serif'
    Bubblegum_Sans = 'Bubblegum Sans'
    Bubbler_One = 'Bubbler One'
    Buda = 'Buda'
    Buenard = 'Buenard'
    Bungee = 'Bungee'
    Bungee_Hairline = 'Bungee Hairline'
    Bungee_Inline = 'Bungee Inline'
    Bungee_Outline = 'Bungee Outline'
    Bungee_Shade = 'Bungee Shade'
    Butcherman = 'Butcherman'
    Butterfly_Kids = 'Butterfly Kids'
    Cabin = 'Cabin'
    Cabin_Condensed = 'Cabin Condensed'
    Cabin_Sketch = 'Cabin Sketch'
    Caesar_Dressing = 'Caesar Dressing'
    Cagliostro = 'Cagliostro'
    Cairo = 'Cairo'
    Caladea = 'Caladea'
    Calistoga = 'Calistoga'
    Calligraffitti = 'Calligraffitti'
    Cambay = 'Cambay'
    Cambo = 'Cambo'
    Candal = 'Candal'
    Cantarell = 'Cantarell'
    Cantata_One = 'Cantata One'
    Cantora_One = 'Cantora One'
    Capriola = 'Capriola'
    Cardo = 'Cardo'
    Carme = 'Carme'
    Carrois_Gothic = 'Carrois Gothic'
    Carrois_Gothic_SC = 'Carrois Gothic SC'
    Carter_One = 'Carter One'
    Catamaran = 'Catamaran'
    Caudex = 'Caudex'
    Caveat = 'Caveat'
    Caveat_Brush = 'Caveat Brush'
    Cedarville_Cursive = 'Cedarville Cursive'
    Ceviche_One = 'Ceviche One'
    Chakra_Petch = 'Chakra Petch'
    Changa = 'Changa'
    Changa_One = 'Changa One'
    Chango = 'Chango'
    Charm = 'Charm'
    Charmonman = 'Charmonman'
    Chathura = 'Chathura'
    Chau_Philomene_One = 'Chau Philomene One'
    Chela_One = 'Chela One'
    Chelsea_Market = 'Chelsea Market'
    Chenla = 'Chenla'
    Cherry_Cream_Soda = 'Cherry Cream Soda'
    Cherry_Swash = 'Cherry Swash'
    Chewy = 'Chewy'
    Chicle = 'Chicle'
    Chilanka = 'Chilanka'
    Chivo = 'Chivo'
    Chonburi = 'Chonburi'
    Cinzel = 'Cinzel'
    Cinzel_Decorative = 'Cinzel Decorative'
    Clicker_Script = 'Clicker Script'
    Coda = 'Coda'
    Coda_Caption = 'Coda Caption'
    Codystar = 'Codystar'
    Coiny = 'Coiny'
    Combo = 'Combo'
    Comfortaa = 'Comfortaa'
    Comic_Neue = 'Comic Neue'
    Coming_Soon = 'Coming Soon'
    Concert_One = 'Concert One'
    Condiment = 'Condiment'
    Content = 'Content'
    Contrail_One = 'Contrail One'
    Convergence = 'Convergence'
    Cookie = 'Cookie'
    Copse = 'Copse'
    Corben = 'Corben'
    Cormorant = 'Cormorant'
    Cormorant_Garamond = 'Cormorant Garamond'
    Cormorant_Infant = 'Cormorant Infant'
    Cormorant_SC = 'Cormorant SC'
    Cormorant_Unicase = 'Cormorant Unicase'
    Cormorant_Upright = 'Cormorant Upright'
    Courgette = 'Courgette'
    Courier_Prime = 'Courier Prime'
    Cousine = 'Cousine'
    Coustard = 'Coustard'
    Covered_By_Your_Grace = 'Covered By Your Grace'
    Crafty_Girls = 'Crafty Girls'
    Creepster = 'Creepster'
    Crete_Round = 'Crete Round'
    Crimson_Pro = 'Crimson Pro'
    Crimson_Text = 'Crimson Text'
    Croissant_One = 'Croissant One'
    Crushed = 'Crushed'
    Cuprum = 'Cuprum'
    Cute_Font = 'Cute Font'
    Cutive = 'Cutive'
    Cutive_Mono = 'Cutive Mono'
    DM_Mono = 'DM Mono'
    DM_Sans = 'DM Sans'
    DM_Serif_Display = 'DM Serif Display'
    DM_Serif_Text = 'DM Serif Text'
    Damion = 'Damion'
    Dancing_Script = 'Dancing Script'
    Dangrek = 'Dangrek'
    Darker_Grotesque = 'Darker Grotesque'
    David_Libre = 'David Libre'
    Dawning_of_a_New_Day = 'Dawning of a New Day'
    Days_One = 'Days One'
    Dekko = 'Dekko'
    Delius = 'Delius'
    Delius_Swash_Caps = 'Delius Swash Caps'
    Delius_Unicase = 'Delius Unicase'
    Della_Respira = 'Della Respira'
    Denk_One = 'Denk One'
    Devonshire = 'Devonshire'
    Dhurjati = 'Dhurjati'
    Didact_Gothic = 'Didact Gothic'
    Diplomata = 'Diplomata'
    Diplomata_SC = 'Diplomata SC'
    Do_Hyeon = 'Do Hyeon'
    Dokdo = 'Dokdo'
    Domine = 'Domine'
    Donegal_One = 'Donegal One'
    Doppio_One = 'Doppio One'
    Dorsa = 'Dorsa'
    Dosis = 'Dosis'
    Dr_Sugiyama = 'Dr Sugiyama'
    Duru_Sans = 'Duru Sans'
    Dynalight = 'Dynalight'
    EB_Garamond = 'EB Garamond'
    Eagle_Lake = 'Eagle Lake'
    East_Sea_Dokdo = 'East Sea Dokdo'
    Eater = 'Eater'
    Economica = 'Economica'
    Eczar = 'Eczar'
    El_Messiri = 'El Messiri'
    Electrolize = 'Electrolize'
    Elsie = 'Elsie'
    Elsie_Swash_Caps = 'Elsie Swash Caps'
    Emblema_One = 'Emblema One'
    Emilys_Candy = 'Emilys Candy'
    Encode_Sans = 'Encode Sans'
    Encode_Sans_Condensed = 'Encode Sans Condensed'
    Encode_Sans_Expanded = 'Encode Sans Expanded'
    Encode_Sans_Semi_Condensed = 'Encode Sans Semi Condensed'
    Encode_Sans_Semi_Expanded = 'Encode Sans Semi Expanded'
    Engagement = 'Engagement'
    Englebert = 'Englebert'
    Enriqueta = 'Enriqueta'
    Epilogue = 'Epilogue'
    Erica_One = 'Erica One'
    Esteban = 'Esteban'
    Euphoria_Script = 'Euphoria Script'
    Ewert = 'Ewert'
    Exo = 'Exo'
    Exo_2 = 'Exo 2'
    Expletus_Sans = 'Expletus Sans'
    Fahkwang = 'Fahkwang'
    Fanwood_Text = 'Fanwood Text'
    Farro = 'Farro'
    Farsan = 'Farsan'
    Fascinate = 'Fascinate'
    Fascinate_Inline = 'Fascinate Inline'
    Faster_One = 'Faster One'
    Fasthand = 'Fasthand'
    Fauna_One = 'Fauna One'
    Faustina = 'Faustina'
    Federant = 'Federant'
    Federo = 'Federo'
    Felipa = 'Felipa'
    Fenix = 'Fenix'
    Finger_Paint = 'Finger Paint'
    Fira_Code = 'Fira Code'
    Fira_Mono = 'Fira Mono'
    Fira_Sans = 'Fira Sans'
    Fira_Sans_Condensed = 'Fira Sans Condensed'
    Fira_Sans_Extra_Condensed = 'Fira Sans Extra Condensed'
    Fjalla_One = 'Fjalla One'
    Fjord_One = 'Fjord One'
    Flamenco = 'Flamenco'
    Flavors = 'Flavors'
    Fondamento = 'Fondamento'
    Fontdiner_Swanky = 'Fontdiner Swanky'
    Forum = 'Forum'
    Francois_One = 'Francois One'
    Frank_Ruhl_Libre = 'Frank Ruhl Libre'
    Freckle_Face = 'Freckle Face'
    Fredericka_the_Great = 'Fredericka the Great'
    Fredoka_One = 'Fredoka One'
    Freehand = 'Freehand'
    Fresca = 'Fresca'
    Frijole = 'Frijole'
    Fruktur = 'Fruktur'
    Fugaz_One = 'Fugaz One'
    GFS_Didot = 'GFS Didot'
    GFS_Neohellenic = 'GFS Neohellenic'
    Gabriela = 'Gabriela'
    Gaegu = 'Gaegu'
    Gafata = 'Gafata'
    Galada = 'Galada'
    Galdeano = 'Galdeano'
    Galindo = 'Galindo'
    Gamja_Flower = 'Gamja Flower'
    Gayathri = 'Gayathri'
    Gelasio = 'Gelasio'
    Gentium_Basic = 'Gentium Basic'
    Gentium_Book_Basic = 'Gentium Book Basic'
    Geo = 'Geo'
    Geostar = 'Geostar'
    Geostar_Fill = 'Geostar Fill'
    Germania_One = 'Germania One'
    Gidugu = 'Gidugu'
    Gilda_Display = 'Gilda Display'
    Girassol = 'Girassol'
    Give_You_Glory = 'Give You Glory'
    Glass_Antiqua = 'Glass Antiqua'
    Glegoo = 'Glegoo'
    Gloria_Hallelujah = 'Gloria Hallelujah'
    Goblin_One = 'Goblin One'
    Gochi_Hand = 'Gochi Hand'
    Gorditas = 'Gorditas'
    Gothic_A1 = 'Gothic A1'
    Gotu = 'Gotu'
    Goudy_Bookletter_1911 = 'Goudy Bookletter 1911'
    Graduate = 'Graduate'
    Grand_Hotel = 'Grand Hotel'
    Gravitas_One = 'Gravitas One'
    Great_Vibes = 'Great Vibes'
    Grenze = 'Grenze'
    Grenze_Gotisch = 'Grenze Gotisch'
    Griffy = 'Griffy'
    Gruppo = 'Gruppo'
    Gudea = 'Gudea'
    Gugi = 'Gugi'
    Gupter = 'Gupter'
    Gurajada = 'Gurajada'
    Habibi = 'Habibi'
    Halant = 'Halant'
    Hammersmith_One = 'Hammersmith One'
    Hanalei = 'Hanalei'
    Hanalei_Fill = 'Hanalei Fill'
    Handlee = 'Handlee'
    Hanuman = 'Hanuman'
    Happy_Monkey = 'Happy Monkey'
    Harmattan = 'Harmattan'
    Headland_One = 'Headland One'
    Heebo = 'Heebo'
    Henny_Penny = 'Henny Penny'
    Hepta_Slab = 'Hepta Slab'
    Herr_Von_Muellerhoff = 'Herr Von Muellerhoff'
    Hi_Melody = 'Hi Melody'
    Hind = 'Hind'
    Hind_Guntur = 'Hind Guntur'
    Hind_Madurai = 'Hind Madurai'
    Hind_Siliguri = 'Hind Siliguri'
    Hind_Vadodara = 'Hind Vadodara'
    Holtwood_One_SC = 'Holtwood One SC'
    Homemade_Apple = 'Homemade Apple'
    Homenaje = 'Homenaje'
    IBM_Plex_Mono = 'IBM Plex Mono'
    IBM_Plex_Sans = 'IBM Plex Sans'
    IBM_Plex_Sans_Condensed = 'IBM Plex Sans Condensed'
    IBM_Plex_Serif = 'IBM Plex Serif'
    IM_Fell_DW_Pica = 'IM Fell DW Pica'
    IM_Fell_DW_Pica_SC = 'IM Fell DW Pica SC'
    IM_Fell_Double_Pica = 'IM Fell Double Pica'
    IM_Fell_Double_Pica_SC = 'IM Fell Double Pica SC'
    IM_Fell_English = 'IM Fell English'
    IM_Fell_English_SC = 'IM Fell English SC'
    IM_Fell_French_Canon = 'IM Fell French Canon'
    IM_Fell_French_Canon_SC = 'IM Fell French Canon SC'
    IM_Fell_Great_Primer = 'IM Fell Great Primer'
    IM_Fell_Great_Primer_SC = 'IM Fell Great Primer SC'
    Ibarra_Real_Nova = 'Ibarra Real Nova'
    Iceberg = 'Iceberg'
    Iceland = 'Iceland'
    Imprima = 'Imprima'
    Inconsolata = 'Inconsolata'
    Inder = 'Inder'
    Indie_Flower = 'Indie Flower'
    Inika = 'Inika'
    Inknut_Antiqua = 'Inknut Antiqua'
    Inria_Sans = 'Inria Sans'
    Inria_Serif = 'Inria Serif'
    Inter = 'Inter'
    Irish_Grover = 'Irish Grover'
    Istok_Web = 'Istok Web'
    Italiana = 'Italiana'
    Italianno = 'Italianno'
    Itim = 'Itim'
    Jacques_Francois = 'Jacques Francois'
    Jacques_Francois_Shadow = 'Jacques Francois Shadow'
    Jaldi = 'Jaldi'
    Jim_Nightshade = 'Jim Nightshade'
    Jockey_One = 'Jockey One'
    Jolly_Lodger = 'Jolly Lodger'
    Jomhuria = 'Jomhuria'
    Jomolhari = 'Jomolhari'
    Josefin_Sans = 'Josefin Sans'
    Josefin_Slab = 'Josefin Slab'
    Jost = 'Jost'
    Joti_One = 'Joti One'
    Jua = 'Jua'
    Judson = 'Judson'
    Julee = 'Julee'
    Julius_Sans_One = 'Julius Sans One'
    Junge = 'Junge'
    Jura = 'Jura'
    Just_Another_Hand = 'Just Another Hand'
    Just_Me_Again_Down_Here = 'Just Me Again Down Here'
    K2D = 'K2D'
    Kadwa = 'Kadwa'
    Kalam = 'Kalam'
    Kameron = 'Kameron'
    Kanit = 'Kanit'
    Kantumruy = 'Kantumruy'
    Karla = 'Karla'
    Karma = 'Karma'
    Katibeh = 'Katibeh'
    Kaushan_Script = 'Kaushan Script'
    Kavivanar = 'Kavivanar'
    Kavoon = 'Kavoon'
    Kdam_Thmor = 'Kdam Thmor'
    Keania_One = 'Keania One'
    Kelly_Slab = 'Kelly Slab'
    Kenia = 'Kenia'
    Khand = 'Khand'
    Khmer = 'Khmer'
    Khula = 'Khula'
    Kirang_Haerang = 'Kirang Haerang'
    Kite_One = 'Kite One'
    Knewave = 'Knewave'
    KoHo = 'KoHo'
    Kodchasan = 'Kodchasan'
    Kosugi = 'Kosugi'
    Kosugi_Maru = 'Kosugi Maru'
    Kotta_One = 'Kotta One'
    Koulen = 'Koulen'
    Kranky = 'Kranky'
    Kreon = 'Kreon'
    Kristi = 'Kristi'
    Krona_One = 'Krona One'
    Krub = 'Krub'
    Kulim_Park = 'Kulim Park'
    Kumar_One = 'Kumar One'
    Kumar_One_Outline = 'Kumar One Outline'
    Kurale = 'Kurale'
    La_Belle_Aurore = 'La Belle Aurore'
    Lacquer = 'Lacquer'
    Laila = 'Laila'
    Lakki_Reddy = 'Lakki Reddy'
    Lalezar = 'Lalezar'
    Lancelot = 'Lancelot'
    Lateef = 'Lateef'
    Lato = 'Lato'
    League_Script = 'League Script'
    Leckerli_One = 'Leckerli One'
    Ledger = 'Ledger'
    Lekton = 'Lekton'
    Lemon = 'Lemon'
    Lemonada = 'Lemonada'
    Lexend_Deca = 'Lexend Deca'
    Lexend_Exa = 'Lexend Exa'
    Lexend_Giga = 'Lexend Giga'
    Lexend_Mega = 'Lexend Mega'
    Lexend_Peta = 'Lexend Peta'
    Lexend_Tera = 'Lexend Tera'
    Lexend_Zetta = 'Lexend Zetta'
    Libre_Barcode_128 = 'Libre Barcode 128'
    Libre_Barcode_128_Text = 'Libre Barcode 128 Text'
    Libre_Barcode_39 = 'Libre Barcode 39'
    Libre_Barcode_39_Extended = 'Libre Barcode 39 Extended'
    Libre_Barcode_39_Extended_Text = 'Libre Barcode 39 Extended Text'
    Libre_Barcode_39_Text = 'Libre Barcode 39 Text'
    Libre_Baskerville = 'Libre Baskerville'
    Libre_Caslon_Display = 'Libre Caslon Display'
    Libre_Caslon_Text = 'Libre Caslon Text'
    Libre_Franklin = 'Libre Franklin'
    Life_Savers = 'Life Savers'
    Lilita_One = 'Lilita One'
    Lily_Script_One = 'Lily Script One'
    Limelight = 'Limelight'
    Linden_Hill = 'Linden Hill'
    Literata = 'Literata'
    Liu_Jian_Mao_Cao = 'Liu Jian Mao Cao'
    Livvic = 'Livvic'
    Lobster = 'Lobster'
    Lobster_Two = 'Lobster Two'
    Londrina_Outline = 'Londrina Outline'
    Londrina_Shadow = 'Londrina Shadow'
    Londrina_Sketch = 'Londrina Sketch'
    Londrina_Solid = 'Londrina Solid'
    Long_Cang = 'Long Cang'
    Lora = 'Lora'
    Love_Ya_Like_A_Sister = 'Love Ya Like A Sister'
    Loved_by_the_King = 'Loved by the King'
    Lovers_Quarrel = 'Lovers Quarrel'
    Luckiest_Guy = 'Luckiest Guy'
    Lusitana = 'Lusitana'
    Lustria = 'Lustria'
    M_PLUS_1p = 'M PLUS 1p'
    M_PLUS_Rounded_1c = 'M PLUS Rounded 1c'
    Ma_Shan_Zheng = 'Ma Shan Zheng'
    Macondo = 'Macondo'
    Macondo_Swash_Caps = 'Macondo Swash Caps'
    Mada = 'Mada'
    Magra = 'Magra'
    Maiden_Orange = 'Maiden Orange'
    Maitree = 'Maitree'
    Major_Mono_Display = 'Major Mono Display'
    Mako = 'Mako'
    Mali = 'Mali'
    Mallanna = 'Mallanna'
    Mandali = 'Mandali'
    Manjari = 'Manjari'
    Manrope = 'Manrope'
    Mansalva = 'Mansalva'
    Manuale = 'Manuale'
    Marcellus = 'Marcellus'
    Marcellus_SC = 'Marcellus SC'
    Marck_Script = 'Marck Script'
    Margarine = 'Margarine'
    Markazi_Text = 'Markazi Text'
    Marko_One = 'Marko One'
    Marmelad = 'Marmelad'
    Martel = 'Martel'
    Martel_Sans = 'Martel Sans'
    Marvel = 'Marvel'
    Mate = 'Mate'
    Mate_SC = 'Mate SC'
    Maven_Pro = 'Maven Pro'
    McLaren = 'McLaren'
    Meddon = 'Meddon'
    MedievalSharp = 'MedievalSharp'
    Medula_One = 'Medula One'
    Meera_Inimai = 'Meera Inimai'
    Megrim = 'Megrim'
    Meie_Script = 'Meie Script'
    Merienda = 'Merienda'
    Merienda_One = 'Merienda One'
    Merriweather = 'Merriweather'
    Merriweather_Sans = 'Merriweather Sans'
    Metal = 'Metal'
    Metal_Mania = 'Metal Mania'
    Metamorphous = 'Metamorphous'
    Metrophobic = 'Metrophobic'
    Michroma = 'Michroma'
    Milonga = 'Milonga'
    Miltonian = 'Miltonian'
    Miltonian_Tattoo = 'Miltonian Tattoo'
    Mina = 'Mina'
    Miniver = 'Miniver'
    Miriam_Libre = 'Miriam Libre'
    Mirza = 'Mirza'
    Miss_Fajardose = 'Miss Fajardose'
    Mitr = 'Mitr'
    Modak = 'Modak'
    Modern_Antiqua = 'Modern Antiqua'
    Mogra = 'Mogra'
    Molengo = 'Molengo'
    Molle = 'Molle'
    Monda = 'Monda'
    Monofett = 'Monofett'
    Monoton = 'Monoton'
    Monsieur_La_Doulaise = 'Monsieur La Doulaise'
    Montaga = 'Montaga'
    Montez = 'Montez'
    Montserrat = 'Montserrat'
    Montserrat_Alternates = 'Montserrat Alternates'
    Montserrat_Subrayada = 'Montserrat Subrayada'
    Moul = 'Moul'
    Moulpali = 'Moulpali'
    Mountains_of_Christmas = 'Mountains of Christmas'
    Mouse_Memoirs = 'Mouse Memoirs'
    Mr_Bedfort = 'Mr Bedfort'
    Mr_Dafoe = 'Mr Dafoe'
    Mr_De_Haviland = 'Mr De Haviland'
    Mrs_Saint_Delafield = 'Mrs Saint Delafield'
    Mrs_Sheppards = 'Mrs Sheppards'
    Mukta = 'Mukta'
    Mukta_Mahee = 'Mukta Mahee'
    Mukta_Malar = 'Mukta Malar'
    Mukta_Vaani = 'Mukta Vaani'
    Mulish = 'Mulish'
    MuseoModerno = 'MuseoModerno'
    Mystery_Quest = 'Mystery Quest'
    NTR = 'NTR'
    Nanum_Brush_Script = 'Nanum Brush Script'
    Nanum_Gothic = 'Nanum Gothic'
    Nanum_Gothic_Coding = 'Nanum Gothic Coding'
    Nanum_Myeongjo = 'Nanum Myeongjo'
    Nanum_Pen_Script = 'Nanum Pen Script'
    Neucha = 'Neucha'
    Neuton = 'Neuton'
    New_Rocker = 'New Rocker'
    News_Cycle = 'News Cycle'
    Niconne = 'Niconne'
    Niramit = 'Niramit'
    Nixie_One = 'Nixie One'
    Nobile = 'Nobile'
    Nokora = 'Nokora'
    Norican = 'Norican'
    Nosifer = 'Nosifer'
    Notable = 'Notable'
    Nothing_You_Could_Do = 'Nothing You Could Do'
    Noticia_Text = 'Noticia Text'
    Noto_Sans = 'Noto Sans'
    Noto_Sans_HK = 'Noto Sans HK'
    Noto_Sans_JP = 'Noto Sans JP'
    Noto_Sans_KR = 'Noto Sans KR'
    Noto_Sans_SC = 'Noto Sans SC'
    Noto_Sans_TC = 'Noto Sans TC'
    Noto_Serif = 'Noto Serif'
    Noto_Serif_JP = 'Noto Serif JP'
    Noto_Serif_KR = 'Noto Serif KR'
    Noto_Serif_SC = 'Noto Serif SC'
    Noto_Serif_TC = 'Noto Serif TC'
    Nova_Cut = 'Nova Cut'
    Nova_Flat = 'Nova Flat'
    Nova_Mono = 'Nova Mono'
    Nova_Oval = 'Nova Oval'
    Nova_Round = 'Nova Round'
    Nova_Script = 'Nova Script'
    Nova_Slim = 'Nova Slim'
    Nova_Square = 'Nova Square'
    Numans = 'Numans'
    Nunito = 'Nunito'
    Nunito_Sans = 'Nunito Sans'
    Odibee_Sans = 'Odibee Sans'
    Odor_Mean_Chey = 'Odor Mean Chey'
    Offside = 'Offside'
    Old_Standard_TT = 'Old Standard TT'
    Oldenburg = 'Oldenburg'
    Oleo_Script = 'Oleo Script'
    Oleo_Script_Swash_Caps = 'Oleo Script Swash Caps'
    Open_Sans = 'Open Sans'
    Open_Sans_Condensed = 'Open Sans Condensed'
    Oranienbaum = 'Oranienbaum'
    Orbitron = 'Orbitron'
    Oregano = 'Oregano'
    Orienta = 'Orienta'
    Original_Surfer = 'Original Surfer'
    Oswald = 'Oswald'
    Over_the_Rainbow = 'Over the Rainbow'
    Overlock = 'Overlock'
    Overlock_SC = 'Overlock SC'
    Overpass = 'Overpass'
    Overpass_Mono = 'Overpass Mono'
    Ovo = 'Ovo'
    Oxanium = 'Oxanium'
    Oxygen = 'Oxygen'
    Oxygen_Mono = 'Oxygen Mono'
    PT_Mono = 'PT Mono'
    PT_Sans = 'PT Sans'
    PT_Sans_Caption = 'PT Sans Caption'
    PT_Sans_Narrow = 'PT Sans Narrow'
    PT_Serif = 'PT Serif'
    PT_Serif_Caption = 'PT Serif Caption'
    Pacifico = 'Pacifico'
    Padauk = 'Padauk'
    Palanquin = 'Palanquin'
    Palanquin_Dark = 'Palanquin Dark'
    Pangolin = 'Pangolin'
    Paprika = 'Paprika'
    Parisienne = 'Parisienne'
    Passero_One = 'Passero One'
    Passion_One = 'Passion One'
    Pathway_Gothic_One = 'Pathway Gothic One'
    Patrick_Hand = 'Patrick Hand'
    Patrick_Hand_SC = 'Patrick Hand SC'
    Pattaya = 'Pattaya'
    Patua_One = 'Patua One'
    Pavanam = 'Pavanam'
    Paytone_One = 'Paytone One'
    Peddana = 'Peddana'
    Peralta = 'Peralta'
    Permanent_Marker = 'Permanent Marker'
    Petit_Formal_Script = 'Petit Formal Script'
    Petrona = 'Petrona'
    Philosopher = 'Philosopher'
    Piedra = 'Piedra'
    Pinyon_Script = 'Pinyon Script'
    Pirata_One = 'Pirata One'
    Plaster = 'Plaster'
    Play = 'Play'
    Playball = 'Playball'
    Playfair_Display = 'Playfair Display'
    Playfair_Display_SC = 'Playfair Display SC'
    Podkova = 'Podkova'
    Poiret_One = 'Poiret One'
    Poller_One = 'Poller One'
    Poly = 'Poly'
    Pompiere = 'Pompiere'
    Pontano_Sans = 'Pontano Sans'
    Poor_Story = 'Poor Story'
    Poppins = 'Poppins'
    Port_Lligat_Sans = 'Port Lligat Sans'
    Port_Lligat_Slab = 'Port Lligat Slab'
    Pragati_Narrow = 'Pragati Narrow'
    Prata = 'Prata'
    Preahvihear = 'Preahvihear'
    Press_Start_2P = 'Press Start 2P'
    Pridi = 'Pridi'
    Princess_Sofia = 'Princess Sofia'
    Prociono = 'Prociono'
    Prompt = 'Prompt'
    Prosto_One = 'Prosto One'
    Proza_Libre = 'Proza Libre'
    Public_Sans = 'Public Sans'
    Puritan = 'Puritan'
    Purple_Purse = 'Purple Purse'
    Quando = 'Quando'
    Quantico = 'Quantico'
    Quattrocento = 'Quattrocento'
    Quattrocento_Sans = 'Quattrocento Sans'
    Questrial = 'Questrial'
    Quicksand = 'Quicksand'
    Quintessential = 'Quintessential'
    Qwigley = 'Qwigley'
    Racing_Sans_One = 'Racing Sans One'
    Radley = 'Radley'
    Rajdhani = 'Rajdhani'
    Rakkas = 'Rakkas'
    Raleway = 'Raleway'
    Raleway_Dots = 'Raleway Dots'
    Ramabhadra = 'Ramabhadra'
    Ramaraja = 'Ramaraja'
    Rambla = 'Rambla'
    Rammetto_One = 'Rammetto One'
    Ranchers = 'Ranchers'
    Rancho = 'Rancho'
    Ranga = 'Ranga'
    Rasa = 'Rasa'
    Rationale = 'Rationale'
    Ravi_Prakash = 'Ravi Prakash'
    Recursive = 'Recursive'
    Red_Hat_Display = 'Red Hat Display'
    Red_Hat_Text = 'Red Hat Text'
    Red_Rose = 'Red Rose'
    Redressed = 'Redressed'
    Reem_Kufi = 'Reem Kufi'
    Reenie_Beanie = 'Reenie Beanie'
    Revalia = 'Revalia'
    Rhodium_Libre = 'Rhodium Libre'
    Ribeye = 'Ribeye'
    Ribeye_Marrow = 'Ribeye Marrow'
    Righteous = 'Righteous'
    Risque = 'Risque'
    Roboto = 'Roboto'
    Roboto_Condensed = 'Roboto Condensed'
    Roboto_Mono = 'Roboto Mono'
    Roboto_Slab = 'Roboto Slab'
    Rochester = 'Rochester'
    Rock_Salt = 'Rock Salt'
    Rokkitt = 'Rokkitt'
    Romanesco = 'Romanesco'
    Ropa_Sans = 'Ropa Sans'
    Rosario = 'Rosario'
    Rosarivo = 'Rosarivo'
    Rouge_Script = 'Rouge Script'
    Rowdies = 'Rowdies'
    Rozha_One = 'Rozha One'
    Rubik = 'Rubik'
    Rubik_Mono_One = 'Rubik Mono One'
    Ruda = 'Ruda'
    Rufina = 'Rufina'
    Ruge_Boogie = 'Ruge Boogie'
    Ruluko = 'Ruluko'
    Rum_Raisin = 'Rum Raisin'
    Ruslan_Display = 'Ruslan Display'
    Russo_One = 'Russo One'
    Ruthie = 'Ruthie'
    Rye = 'Rye'
    Sacramento = 'Sacramento'
    Sahitya = 'Sahitya'
    Sail = 'Sail'
    Saira = 'Saira'
    Saira_Condensed = 'Saira Condensed'
    Saira_Extra_Condensed = 'Saira Extra Condensed'
    Saira_Semi_Condensed = 'Saira Semi Condensed'
    Saira_Stencil_One = 'Saira Stencil One'
    Salsa = 'Salsa'
    Sanchez = 'Sanchez'
    Sancreek = 'Sancreek'
    Sansita = 'Sansita'
    Sarabun = 'Sarabun'
    Sarala = 'Sarala'
    Sarina = 'Sarina'
    Sarpanch = 'Sarpanch'
    Satisfy = 'Satisfy'
    Sawarabi_Gothic = 'Sawarabi Gothic'
    Sawarabi_Mincho = 'Sawarabi Mincho'
    Scada = 'Scada'
    Scheherazade = 'Scheherazade'
    Schoolbell = 'Schoolbell'
    Scope_One = 'Scope One'
    Seaweed_Script = 'Seaweed Script'
    Secular_One = 'Secular One'
    Sedgwick_Ave = 'Sedgwick Ave'
    Sedgwick_Ave_Display = 'Sedgwick Ave Display'
    Sen = 'Sen'
    Sevillana = 'Sevillana'
    Seymour_One = 'Seymour One'
    Shadows_Into_Light = 'Shadows Into Light'
    Shadows_Into_Light_Two = 'Shadows Into Light Two'
    Shanti = 'Shanti'
    Share = 'Share'
    Share_Tech = 'Share Tech'
    Share_Tech_Mono = 'Share Tech Mono'
    Shojumaru = 'Shojumaru'
    Short_Stack = 'Short Stack'
    Shrikhand = 'Shrikhand'
    Siemreap = 'Siemreap'
    Sigmar_One = 'Sigmar One'
    Signika = 'Signika'
    Signika_Negative = 'Signika Negative'
    Simonetta = 'Simonetta'
    Single_Day = 'Single Day'
    Sintony = 'Sintony'
    Sirin_Stencil = 'Sirin Stencil'
    Six_Caps = 'Six Caps'
    Skranji = 'Skranji'
    Slabo_13px = 'Slabo 13px'
    Slabo_27px = 'Slabo 27px'
    Slackey = 'Slackey'
    Smokum = 'Smokum'
    Smythe = 'Smythe'
    Sniglet = 'Sniglet'
    Snippet = 'Snippet'
    Snowburst_One = 'Snowburst One'
    Sofadi_One = 'Sofadi One'
    Sofia = 'Sofia'
    Solway = 'Solway'
    Song_Myung = 'Song Myung'
    Sonsie_One = 'Sonsie One'
    Sora = 'Sora'
    Sorts_Mill_Goudy = 'Sorts Mill Goudy'
    Source_Code_Pro = 'Source Code Pro'
    Source_Sans_Pro = 'Source Sans Pro'
    Source_Serif_Pro = 'Source Serif Pro'
    Space_Mono = 'Space Mono'
    Spartan = 'Spartan'
    Special_Elite = 'Special Elite'
    Spectral = 'Spectral'
    Spectral_SC = 'Spectral SC'
    Spicy_Rice = 'Spicy Rice'
    Spinnaker = 'Spinnaker'
    Spirax = 'Spirax'
    Squada_One = 'Squada One'
    Sree_Krushnadevaraya = 'Sree Krushnadevaraya'
    Sriracha = 'Sriracha'
    Srisakdi = 'Srisakdi'
    Staatliches = 'Staatliches'
    Stalemate = 'Stalemate'
    Stalinist_One = 'Stalinist One'
    Stardos_Stencil = 'Stardos Stencil'
    Stint_Ultra_Condensed = 'Stint Ultra Condensed'
    Stint_Ultra_Expanded = 'Stint Ultra Expanded'
    Stoke = 'Stoke'
    Strait = 'Strait'
    Stylish = 'Stylish'
    Sue_Ellen_Francisco = 'Sue Ellen Francisco'
    Suez_One = 'Suez One'
    Sulphur_Point = 'Sulphur Point'
    Sumana = 'Sumana'
    Sunflower = 'Sunflower'
    Sunshiney = 'Sunshiney'
    Supermercado_One = 'Supermercado One'
    Sura = 'Sura'
    Suranna = 'Suranna'
    Suravaram = 'Suravaram'
    Suwannaphum = 'Suwannaphum'
    Swanky_and_Moo_Moo = 'Swanky and Moo Moo'
    Syncopate = 'Syncopate'
    Tajawal = 'Tajawal'
    Tangerine = 'Tangerine'
    Taprom = 'Taprom'
    Tauri = 'Tauri'
    Taviraj = 'Taviraj'
    Teko = 'Teko'
    Telex = 'Telex'
    Tenali_Ramakrishna = 'Tenali Ramakrishna'
    Tenor_Sans = 'Tenor Sans'
    Text_Me_One = 'Text Me One'
    Thasadith = 'Thasadith'
    The_Girl_Next_Door = 'The Girl Next Door'
    Tienne = 'Tienne'
    Tillana = 'Tillana'
    Timmana = 'Timmana'
    Tinos = 'Tinos'
    Titan_One = 'Titan One'
    Titillium_Web = 'Titillium Web'
    Tomorrow = 'Tomorrow'
    Trade_Winds = 'Trade Winds'
    Trirong = 'Trirong'
    Trocchi = 'Trocchi'
    Trochut = 'Trochut'
    Trykker = 'Trykker'
    Tulpen_One = 'Tulpen One'
    Turret_Road = 'Turret Road'
    Ubuntu = 'Ubuntu'
    Ubuntu_Condensed = 'Ubuntu Condensed'
    Ubuntu_Mono = 'Ubuntu Mono'
    Ultra = 'Ultra'
    Uncial_Antiqua = 'Uncial Antiqua'
    Underdog = 'Underdog'
    Unica_One = 'Unica One'
    UnifrakturCook = 'UnifrakturCook'
    UnifrakturMaguntia = 'UnifrakturMaguntia'
    Unkempt = 'Unkempt'
    Unlock = 'Unlock'
    Unna = 'Unna'
    VT323 = 'VT323'
    Vampiro_One = 'Vampiro One'
    Varela = 'Varela'
    Varela_Round = 'Varela Round'
    Varta = 'Varta'
    Vast_Shadow = 'Vast Shadow'
    Vesper_Libre = 'Vesper Libre'
    Viaoda_Libre = 'Viaoda Libre'
    Vibes = 'Vibes'
    Vibur = 'Vibur'
    Vidaloka = 'Vidaloka'
    Viga = 'Viga'
    Voces = 'Voces'
    Volkhov = 'Volkhov'
    Vollkorn = 'Vollkorn'
    Vollkorn_SC = 'Vollkorn SC'
    Voltaire = 'Voltaire'
    Waiting_for_the_Sunrise = 'Waiting for the Sunrise'
    Wallpoet = 'Wallpoet'
    Walter_Turncoat = 'Walter Turncoat'
    Warnes = 'Warnes'
    Wellfleet = 'Wellfleet'
    Wendy_One = 'Wendy One'
    Wire_One = 'Wire One'
    Work_Sans = 'Work Sans'
    Yanone_Kaffeesatz = 'Yanone Kaffeesatz'
    Yantramanav = 'Yantramanav'
    Yatra_One = 'Yatra One'
    Yellowtail = 'Yellowtail'
    Yeon_Sung = 'Yeon Sung'
    Yeseva_One = 'Yeseva One'
    Yesteryear = 'Yesteryear'
    Yrsa = 'Yrsa'
    ZCOOL_KuaiLe = 'ZCOOL KuaiLe'
    ZCOOL_QingKe_HuangYou = 'ZCOOL QingKe HuangYou'
    ZCOOL_XiaoWei = 'ZCOOL XiaoWei'
    Zeyada = 'Zeyada'
    Zhi_Mang_Xing = 'Zhi Mang Xing'
    Zilla_Slab = 'Zilla Slab'
    Zilla_Slab_Highlight = 'Zilla Slab Highlight'

    def __str__(self):
        return '{0}'.format(self.value)


class GradientType(Enum):
    linear = 'linear',
    radial = 'radial'

    def __str__(self):
        return '{0}'.format(self.value)

class FontWeightType(Enum):
    light = 300
    normal = 400
    bold = 700

    def __str__(self):
        return '{0}'.format(self.value)



import functools


def api_call(f):
    @functools.wraps(f)
    def wrapper(self, *args, **kwargs):
        ret = f(self, *args, **kwargs)
        self._check_api_limits()
        return ret

    return wrapper


def api_request(f):
    @functools.wraps(f)
    def wrapper(self, *args, **kwargs):
        ret = f(self, *args, **kwargs)
        self._set_api_limits(ret.status_code, ret.headers)
        return ret

    return wrapper



from .enums import *


class ImageBuilder:

    def __init__(self, text, author=''):
        # type: (str, str) -> ImageBuilder
        # default values
        self.__data = {
            'textFont': FontList.Lora,
            'textColor': '#4f4f4f',
            'textFontWeight': FontWeightType.normal,
            'authorFont': FontList.Lato,
            'authorColor': '#e5e5e5',
            'authorFontWeight': FontWeightType.normal,
            'highlightColor': 'transparent',
            'backgroundColor1': '#000000',
            'backgroundColor2': '#000000',
            'logoUrl': 'https://cdn.ritekit.com/assets/img/common/made-with-ritekit-white.png',
            'width': 400,
            'height': 400
        }
        self.text(text).author(author)

    def text(self, text):
        # type: (str) -> ImageBuilder
        self.__data['text'] = text
        return self

    def author(self, text):
        # type: (str) -> ImageBuilder
        self.__data['author'] = text
        return self

    def text_font(self, font):
        # type: (FontList) -> ImageBuilder
        self.__data['quoteFont'] = font
        return self

    def text_font_color(self, color):
        # type: (int) -> ImageBuilder
        self.__data['quoteFontColor'] = color
        return self

    def text_font_weight(self, weight):
        # type: (int) -> ImageBuilder
        self.__data['textFontWeight'] = weight
        return self

    def author_font(self, font):
        # type: (FontList) -> ImageBuilder
        self.__data['authorFont'] = font
        return self

    def author_color(self, color):
        # type: (FontList) -> ImageBuilder
        self.__data['authorColor'] = color
        return self

    def background_color1(self, color):
        # type: (str) -> ImageBuilder
        self.__data['backgroundColor1'] = color
        return self

    def background_color2(self, color):
        # type: (str) -> ImageBuilder
        self.__data['backgroundColor2'] = color
        return self

    def brand_logo(self, url):
        # type: (str) -> ImageBuilder
        self.__data['brandLogo'] = url
        return self

    def width(self, width):
        # type: (int) -> ImageBuilder
        self.__data['width'] = width
        return self

    def height(self, height):
        # type: (int) -> ImageBuilder
        self.__data['height'] = height
        return self

    def build(self):
        return self.__data



import os


def read_env_file(env_file):
    with open(env_file, 'r') as fh:
        vars_dict = {
            tuple(line.split('=')) for line in fh.readlines() if not line.startswith('#')
        }
    os.environ.update(vars_dict)
    return vars_dict


def get_env(name, default=None):
    return os.getenv(name, default)



from datetime import date

from requests import Response, get

from .exceptions import *
import shutil

HASHTAG_COLORS = {
    0: 'UNDERUSED',
    1: 'OVERUSED',
    2: 'LONG_LIFE',
    3: 'HOT_NOW',
    4: 'ONLY_ON_INSTAGRAM',
    5: 'BANNED_ON_INSTAGRAM',
}


class Hashtag:

    def __init__(self, json):
        self.__data = json

    @property
    def hashtag(self):
        # type: () -> str
        return self.__data['hashtag'] if 'hashtag' in self.__data else self.__data['tag']

    @property
    def tweets(self):
        # type: () -> int
        return self.__data['tweets']

    @property
    def exposure(self):
        # type: () -> int
        return self.__data['exposure']

    @property
    def retweets(self):
        # type: () -> int
        return self.__data['retweets']

    @property
    def images(self):
        # type: () -> float
        return self.__data['images'] if 'images' in self.__data else self.__data['photos']

    @property
    def links(self):
        # type: () -> float
        return self.__data['links']

    @property
    def mentions(self):
        # type: () -> float
        return self.__data['mentions']

    @property
    def color(self):
        # type: () -> int
        return self.__data['color']

    @property
    def color_verbose(self):
        # type: () -> str
        return HASHTAG_COLORS[self.color]

    @property
    def media_count(self):
        # type: () -> int
        return self.__data['mediaCount'] if 'mediaCount' in self.__data else None

    def __str__(self):
        # type: () -> str
        output_format = '==== Stats of #{} ====\ntweets: {}\nretweets: {}\nexposure: {}\n' \
                        'mentions: {}%\nlinks: {}%\nimages: {}%\ncolor: {}\nmedia count: {}\n'
        return output_format.format(
            self.hashtag,
            self.tweets,
            self.retweets,
            self.exposure,
            self.mentions * 100,
            self.links * 100,
            self.images * 100,
            self.color_verbose,
            self.media_count
        )


class HashtagHistory:

    def __init__(self, json):
        self.__data = json

    @property
    def hashtag(self):
        # type: () -> str
        return self.__data['tag']

    @property
    def date_str(self):
        # type: () -> str
        return self.__data['date']

    @property
    def date(self):
        # type: () -> date
        date_str = [int(x) for x in self.date_str.split(' ')[0].split('-')]
        return date(date_str[0], date_str[1], date_str[2])

    @property
    def tweets(self):
        # type: () -> int
        return self.__data['tweets']

    @property
    def retweets(self):
        # type: () -> int
        return self.__data['retweets']

    @property
    def links(self):
        # type: () -> float
        return self.__data['links']

    @property
    def images(self):
        # type: () -> float
        return self.__data['images']

    @property
    def mentions(self):
        # type: () -> float
        return self.__data['mentions']

    @property
    def color(self):
        # type: () -> int
        return self.__data['color']

    @property
    def color_verbose(self):
        # type: () -> str
        return HASHTAG_COLORS[self.color]

    @property
    def exposure(self):
        # type: () -> int
        return self.__data['exposure']

    def __str__(self):
        # type: () -> str
        output_format = '==== Stats of #{} ====\ndate: {}\ntweets: {}\nretweets: {}\nexposure: {}\n' \
                        'mentions: {}%\nlinks: {}%\nimages: {}%\ncolor: {}\n'
        return output_format.format(
            self.hashtag,
            self.date,
            self.tweets,
            self.retweets,
            self.exposure,
            self.mentions * 100,
            self.links * 100,
            self.images * 100,
            self.color_verbose
        )


class InstagramBannedHashtag:

    def __init__(self, post, banned_hashtag):
        # type: (str, [str]) -> InstagramBannedHashtag
        self.post = post
        self.banned_hashtags = banned_hashtag

    def __str__(self):
        # type: () -> str
        return '{} banned: {}'.format(self.post, ', '.join(self.banned_hashtags))


class Image:

    def __init__(self, content_type, content):
        self.content_type = content_type
        self.content = content
        self.ext = self.get_ext()

    def save(self, target_directory, filename_without_ext):
        # type: (str, str) -> str
        path = '{}/{}.{}'.format(target_directory, filename_without_ext, self.ext)
        with open(path, 'wb') as out_file:
            shutil.copyfileobj(self.content, out_file)
        return path

    def get_ext(self):
        ct = self.content_type
        if ct == 'image/png':
            return 'png'
        elif ct in ['image/jpg', 'image/jpeg']:
            return 'jpg'
        elif ct == 'image/gif':
            return 'gif'

        raise ImageFormatException('Unknown image format')


class Cta:

    def __init__(self, json):
        self.__data = json

    @property
    def id(self):
        # type: () -> int
        return self.__data['id']

    @property
    def name(self):
        # type: () -> str
        return self.__data['name']

    def __str__(self):
        # type: () -> str
        return '{} id:{}'.format(self.name, self.id)


class Link:

    def __init__(self, url, original, service, cta_id):
        # type: (str, str, str, int) -> Link
        self.url = url
        self.original = original
        self.service = service
        self.cta_id = cta_id

    def __str__(self):
        # type: () -> str
        return '{} ({}) service: {}, cta: {}'.format(self.url, self.original, self.service, self.cta_id)


class ArticleForUrl:

    def __init__(self, url, title, text):
        # type: (str, str, str) -> ArticleForUrl
        self.url = url
        self.title = title
        self.text = text

    def __str__(self):
        # type: () -> str
        return '{} - title: {}\ntext: {}'.format(self.url, self.title, self.text)


class Logo:

    def __init__(self, response):
        self.response = response

    @property
    def is_found(self):
        return self.response['result']

    @property
    def is_generated(self):
        return self.response['isGenerated'] if self.is_found else False

    def logo(self, permanent=False):
        if self.is_found:
            return self.__get_image('originalLogo', permanent)
        raise RiteTagException('Logo not found')

    def logo_content_type(self, permanent=False):
        if self.is_found:
            return self.__get_image_content_type('originalLogo', permanent)
        raise RiteTagException('Logo not found')

    def square_logo(self, permanent=False):
        if self.is_found:
            return self.__get_image('squareLogo', permanent)
        raise RiteTagException('Logo not found')

    def square_logo_content_type(self, permanent=False):
        if self.is_found:
            return self.__get_image_content_type('squareLogo', permanent)
        raise RiteTagException('Logo not found')

    def __get_image(self, type, permanent):
        url_type = 'permanentUrl' if permanent else 'url'
        l = self.response[type]
        for content_type in ['svg', 'png', 'webp', 'jpg']:
            if content_type in l[url_type]:
                return l[url_type][content_type]

    def __get_image_content_type(self, type, permanent):
        url_type = 'permanentUrl' if permanent else 'url'
        l = self.response[type]
        for content_type in ['svg', 'png', 'webp', 'jpg']:
            if content_type in l[url_type]:
                return content_type


class Parser:
    @staticmethod
    def _handle_error_message(json):
        # type: (dict) -> None
        if not json['result']:
            raise RiteTagException(json['message'])

    @staticmethod
    def download_file(url, filename):
        r = get(url, allow_redirects=True)
        f = open(filename, "wb")
        f.write(r.content)
        f.close()

    @staticmethod
    def hashtag_list(json, key):
        # type: (dict, str) -> [Hashtag]
        Parser._handle_error_message(json)
        return [Hashtag(x) for x in json[key]]

    @staticmethod
    def get_text(json, key):
        # type: (dict, str) -> str
        Parser._handle_error_message(json)
        return json[key]

    @staticmethod
    def history(json):
        # type: (dict) -> [HashtagHistory]
        Parser._handle_error_message(json)
        return [HashtagHistory(x) for x in json['data']]

    @staticmethod
    def banned_instagram_hashtags(json):
        # type: (dict) -> InstagramBannedHashtag
        Parser._handle_error_message(json)
        return InstagramBannedHashtag(json['post'], json['bannedHashtags'])

    @staticmethod
    def emoji(json):
        # type: (dict) -> str
        Parser._handle_error_message(json)
        return json['emojis']

    @staticmethod
    def image(response, external=False):
        # type: (Response, bool) -> Image
        try:
            return Image(response.headers['Content-Type'], response.raw)
        except ImageFormatException:
            if external:
                raise ImageFormatException
            json = response.json()
            raise RiteTagException(json['message'])

    @staticmethod
    def cta_list(json):
        # type: (dict) -> [Cta]
        Parser._handle_error_message(json)
        return [Cta(v) for k,v in json['list'].items()]

    @staticmethod
    def link(json):
        # type: (dict) -> Link
        Parser._handle_error_message(json)
        return Link(json['url'], json['original'], json['service'], json['ctaId'])

    @staticmethod
    def url_from_image(json):
        # type: (dict) -> str
        Parser._handle_error_message(json)
        return json['url']

    @staticmethod
    def free_mail_detection(json):
        # type: (dict) -> bool
        return json['freemail']

    @staticmethod
    def disposable_email_detection(json):
        # type: (dict) -> bool
        return json['disposable']

    @staticmethod
    def email_typo(json):
        # type: (dict) -> [str]
        return json['suggestions']

    @staticmethod
    def company_logo(json):
        # type: (dict) -> [str]
        return json['url']

    @staticmethod
    def company_logo_2(json):
        # type: (dict) -> [str]
        return Logo(json)

    @staticmethod
    def name_from_email_address(json):
        # type: (dict) -> str
        return json['info']

    @staticmethod
    def article_for_url(json):
        # type: (dict) -> ArticleForUrl
        return ArticleForUrl(json['url'], json['title'], json['text'])


class Limit:

    def __init__(self, limit, used, reset):
        self.limit = int(limit)
        self. used = int(used)
        reset_date = [int(x) for x in reset.split(' ')[0].split('-')]
        self.reset = date(reset_date[0], reset_date[1], reset_date[2])

    @property
    def usage(self):
        # type: () -> float
        return round((float(self.used) / self.limit) * 100, 2)

    def __str__(self):
        # type: () -> str
        return 'Used {}% of API credits. The limit resets on {}.'.format(self.usage, self.reset)





import argparse
import os
from .api import *

current_directory = os.getcwd()
access_token = os.getenv('ACCESS_TOKEN', None)
require_token = access_token is None


class Action(Enum):
    hashtag_stats = 'hashtag_stats'
    auto_hashtags = 'auto_hashtags'
    hashtag_suggestions_for_text = 'hashtag_suggestions_for_text'
    hashtag_suggestions_for_image = 'hashtag_suggestions_for_image'
    hashtag_history = 'hashtag_history'
    emojis_suggestion = 'emojis_suggestion'
    auto_emojify = 'auto_emojify'
    text_to_image = 'text_to_image'
    animate_image = 'animate_image'
    company_logo = 'company_logo'
    list_of_cta = 'list_of_cta'
    shorten_link = 'shorten_link'

    def __str__(self):
        return '{0}'.format(self.value)


actions = [str(x) for x in [
    Action.hashtag_stats,
    Action.auto_hashtags,
    Action.hashtag_suggestions_for_text,
    Action.hashtag_suggestions_for_image,
    Action.hashtag_history,
    Action.emojis_suggestion,
    Action.auto_emojify,
    # Action.text_to_image, not supported yet
    # Action.animate_image, not supported yet
    Action.company_logo,
    Action.list_of_cta,
    Action.shorten_link
]]


def get_hashtags(parser, args):
    if args.hashtags is None or len(args.hashtags) == 0:
        parser.error('missing hashtags')
    return args.hashtags


def get_hashtag(parser, args):
    if args.hashtags is None or len(args.hashtags) == 0:
        parser.error('missing hashtag')
    elif len(args.hashtags) > 1:
        parser.error('too many hashtags')
    return args.hashtags[0]


def get_domain(parser, args):
    if args.hashtags is None or len(args.hashtags) == 0:
        parser.error('missing domain')
    elif len(args.hashtags) > 1:
        parser.error('invalid domain')
    return args.hashtags[0]


def get_url(parser, args):
    if args.hashtags is None or len(args.hashtags) == 0:
        parser.error('missing url')
    elif len(args.hashtags) > 1:
        parser.error('invalid url')
    return args.hashtags[0]


def get_post(parser, args):
    if args.hashtags is None or len(args.hashtags) == 0:
        parser.error('missing post')
    return ' '.join(args.hashtags)


def run():
    parser = argparse.ArgumentParser(description='RiteTag API console client.')
    parser.add_argument('-t', '--access_token', type=str, help='access token', required=require_token)
    parser.add_argument('action', choices=actions, help='action')
    parser.add_argument('hashtags', type=str, nargs='*', help='hashtags')
    parser.add_argument('-m', '--max_hashtags', type=int, default=2)
    parser.add_argument('-p', '--hashtag_position', type=str, choices=['auto', 'end'], default='auto')
    parser.add_argument('-f', '--filename', type=str)
    parser.add_argument('-ci', '--cta_id', type=int)
    parser.add_argument('-g', '--auto_generate', type=str, choices=['1', '0'], default='1')
    args = parser.parse_args()

    api = RiteTagApi(args.access_token if require_token else access_token)

    def log(limit):
        print(limit)

    api.on_limit(0, log)

    a = Action[args.action]

    # print(args)
    try:
        if a == Action.hashtag_stats:
            hashtags = get_hashtags(parser, args)
            print('\n'.join([str(x) for x in api.hashtag_stats(hashtags)]))

        elif a == Action.auto_hashtags:
            post = get_post(parser, args)
            log(api.auto_hashtag(post, args.max_hashtags))

        elif a == Action.hashtag_suggestions_for_text:
            post = get_post(parser, args)
            [log(x) for x in api.hashtag_suggestion_for_text(post)]

        elif a == Action.hashtag_suggestions_for_image:
            post = get_url(parser, args)
            [log(x) for x in api.hashtag_suggestion_for_image(post)]

        elif a == Action.hashtag_history:
            hashtag = get_hashtag(parser, args)
            [log(x) for x in api.history(hashtag)]

        elif a == Action.emojis_suggestion:
            text = get_post(parser, args)
            log(', '.join(api.emoji_suggestion(text)))

        elif a == Action.auto_emojify:
            text = get_post(parser, args)
            log(api.auto_emojify(text))

        elif a == Action.text_to_image:
            parser.error("not implemented yet")

        elif a == Action.animate_image:
            parser.error('not implemented yet')

        elif a == Action.company_logo:
            domain = get_domain(parser, args)
            log('Looking for logo - {}'.format(domain))
            logo = api.company_logo_2(domain, True if args.auto_generate == '1' else False)
            filename = domain.replace('.', '_') if args.filename is None else args.filename

            if logo.is_generated:
                log("Logo is generated.")

            log("Downloading logo - {}".format(domain))
            try:
                original_path = '{}.{}'.format(filename, logo.logo_content_type())
                Parser.download_file(logo.logo(), original_path)
                log('Image is saved {} - {}'.format(original_path, domain))
            except RiteTagException as e:
                log('Error {} - {}'.format(e, domain))

            log("Downloading square logo - {}".format(domain))
            try:
                square_path = '{}_square.{}'.format(filename, logo.square_logo_content_type())
                Parser.download_file(logo.square_logo(), square_path)
                log('Image is saved {} - {}'.format(domain, square_path))
            except RiteTagException as e:
                log('Error {} - {}'.format(e, domain))

        elif a == Action.list_of_cta:
            [log(x) for x in api.list_of_cta()]

        elif a == Action.shorten_link:
            url = get_domain(parser, args)
            cta_id = args.cta_id
            log(api.shorten_url(url, cta_id).url)
    except RiteTagException as e:
        parser.error(e)
        # raise e



import requests
import base64
import re

from .decorators import api_call, api_request
from .response import *
from .builders import *
from .exceptions import RiteTagException, ImageFormatException
try:
    # python2
    from urlparse import urlparse
except:
    # python3
    from urllib.parse import urlparse


class RiteTagApi:

    def __init__(self, client_id):
        # type: (str) -> RiteTagApi
        self.base_uri = 'https://api.ritekit.com'
        self.client_id = client_id
        self.limit = None
        self.callbacks = []

    def _get_headers(self, json=False):
        # type (bool) -> dict
        headers = {
            'User-Agent': 'RiteTag API client 1.0',
            'Authorization': 'Bearer {}'.format(self.client_id)
        }
        if json:
            headers['Content-Type'] = 'application/json'
        return headers

    def _set_api_limits(self, code, headers):
        # type: (int, dict) -> None
        if code == 401:
            raise RiteTagException('Invalid or expired token')

        keys = ['X-Rate-Limit-Limit', 'X-Rate-Limit-Used', 'X-Rate-Limit-Reset']
        exists = all([x in headers for x in keys])

        if exists:
            self.limit = Limit(
                headers[keys[0]],
                headers[keys[1]],
                headers[keys[2]],
            )
        else:
            raise RiteTagException('Something went wrong.')

    def _check_api_limits(self):
        for c in self.callbacks:
            if self.limit.usage >= c[0]:
                c[1](self.limit)

    def _sanitize_hashtag(self, hashtag):
        # type: (str) -> str
        if hashtag is None:
            raise RiteTagException('Invalid hashtag.')
        hashtag = hashtag.strip().lstrip('#')
        if len(hashtag) == 0 or ' ' in hashtag:
            raise RiteTagException('Invalid hashtag.')
        return hashtag

    def _check_scheme(self, url):
        # type: (str) -> str
        scheme_regex = r"^([a-z]+):\/\/"
        f = re.findall(scheme_regex, url)
        if len(f) > 0:
            if f[0] not in ['http', 'https']:
                raise RiteTagException('Invalid scheme')
        else:
            url = 'http://{}'.format(url)
        return url

    def _sanitize_domain(self, domain):
        # type: (str) -> str
        try:
            domain = self._check_scheme(domain)
            result = urlparse(domain)
            if domain != '{}://{}'.format(result.scheme, result.netloc):
                raise RiteTagException('Invalid domain')
            return result.netloc
        except Exception as e:
            raise RiteTagException('Invalid domain')

    def _sanitize_url(self, url):
        # type: (str) -> str
        try:
            url = self._check_scheme(url)
            result = urlparse(url)
            return result.geturl()
        except Exception as e:
            raise RiteTagException('Invalid url')

    def _get_image_from_url(self, url):
        # type: (str) -> Image
        img = requests.request('GET', url, stream=True)
        return Parser.image(img, True)

    @api_request
    def _get_request(self, path, params, stream=False):
        # type: (str, dict, bool) -> Response
        return requests.request('GET', '{}{}'.format(self.base_uri, path),
                                headers=self._get_headers(), params=params, stream=stream)

    @api_request
    def _post_request(self, path, data, params=None, stream=False):
        # type: (str, dict, dict, bool) -> Response
        if params is None:
            params = {}
        resp = requests.request('POST', '{}{}'.format(self.base_uri, path,),
                                headers=self._get_headers(json=True), params=params, json=data, stream=stream)
        return resp

    @api_call
    def hashtag_stats(self, hashtags):
        # type: ([str]) -> [Hashtag]
        """
        Returns real-time stats for up to 100 hashtags. Stats are updated hourly.

        Parameters
        ----------
        hashtags : [str]
             List of hashtag(s) without # mark
        """
        hashtags = map(self._sanitize_hashtag, hashtags)
        response = self._get_request('/v1/stats/multiple-hashtags', {'tags': ','.join(hashtags)})
        return Parser.hashtag_list(response.json(), 'stats')

    @api_call
    def auto_hashtag(self, post, max_hashtags=2,
                     hashtag_position=HashtagPosition.auto):
        # type: (str, int, HashtagPosition) -> str
        """
        Returns auto-hashtagged text of the post.

        Parameters
        ----------
        post : str
            Text up to 1000 characters into which hashtags should be added.
        max_hashtags: int
            Maximum number of hashtags to be added to the text
        hashtag_position: HashtagPosition
            Position of hashtags: end => at the end of the text, auto => anywhere in the text or at the end
        """
        response = self._get_request('/v1/stats/auto-hashtag',
                                     {'post': post, 'maxHashstags': max_hashtags, 'hashtagPosition': hashtag_position})
        return Parser.get_text(response.json(), 'post')

    @api_call
    def hashtag_suggestion_for_text(self, text):
        # type: (str) -> [Hashtag]
        """
        Returns list of hashtag suggestions for a single-word topic or for short block of text (up to 1000 characters).

        Parameters
        ----------
        text : str
            Text up to 1000 characters for which hashtags should be suggested
         """
        response = self._get_request('/v1/stats/hashtag-suggestions', {'text': text})
        return Parser.hashtag_list(response.json(), 'data')

    @api_call
    def hashtag_suggestion_for_image(self, image):
        # type: (str) -> [Hashtag]
        """
        Returns list of hashtag suggestions for an image. Takes into account both semantic
        relevancy as well as real-time hashtag engagement.

        Parameters
        ----------
        image : str
            URL of an image
        """
        try:
            with open(image, "rb") as f:
                result = base64.b64encode(f.read()).decode('utf-8')
        except IOError:
            result = self._sanitize_url(image)

        body = {
            'image': result
        }
        response = self._post_request('/v1/stats/hashtag-suggestions-image', body)
        return Parser.hashtag_list(response.json(), 'data')

    @api_call
    def history(self, hashtag):
        # type: (str) -> [HashtagHistory]
        """
        Returns historical stats for a given hashtag from the last 30 days.
        Add hashtag without hash mark to the URL.

        Parameters
        ----------
        hashtag : str
            Hashtag without # mark
        """
        hashtag = self._sanitize_hashtag(hashtag)
        response = self._get_request('/v1/stats/history/{}'.format(hashtag), {})
        return Parser.history(response.json())

    @api_call
    def trending_hashtags(self, green=True, latin=True):
        # type: (bool, bool) -> [Hashtag]
        """
        Returns list of hashtags currently trending on Twitter.

        Parameters
        ----------
        green : bool
            restrict results only to green hashtags (hot now).
        latin : bool
            restrict results only to hashtags with latin characters
        """
        response = self._get_request('/v1/search/trending', {'green': int(green), 'latin': int(latin)})
        return Parser.hashtag_list(response.json(), 'tags')

    @api_call
    def banned_instagram_hashtags(self, post):
        # type: (str) -> InstagramBannedHashtag
        """
        Detects and removes hashtags banned on Instagram from a list of hashtags.

        Parameters
        ----------
        post : str
            Text up to 1000 characters from which hashtags banned on Instagram should be removed.
        """
        response = self._get_request('/v2/instagram/hashtags-cleaner', {'post': post})
        return Parser.banned_instagram_hashtags(response.json())

    @api_call
    def emoji_suggestion(self, text):
        # type: (str) -> [str]
        """
        Returns list of emoji suggestions for a short block of text (up to 1000 characters).

        Parameters
        ----------
        text : str
            Text up to 1000 characters for which emojis should be suggested.
        """
        response = self._get_request('/v1/emoji/suggestions', {'text': text})
        return Parser.emoji(response.json())

    @api_call
    def auto_emojify(self, text):
        # type : (str) -> str
        """
        Returns text of the post with emoji added

        Parameters
        ----------
        text: str
            Text up to 1000 characters into which emojis should be added.
        """
        response = self._get_request('/v1/emoji/auto-emojify', {'text': text})
        return Parser.get_text(response.json(), 'text')

    @api_call
    def text_to_image(self, image_builder):
        # type: (ImageBuilder) -> Image
        """
        Returns an image created from text according to given style parameters

        Parameters
        ----------
        image_builder : ImageBuilder
            see ImageBuilder
        """
        response = self._get_request('/v2/image/quote', params=image_builder.build(), stream=True)
        return Parser.image(response)

    @api_call
    def animate_image(self, url, animation_type=AnimationType.glint):
        # type: (str, AnimationType) -> Image
        """
        Returns an animated GIF.

        Parameters
        ----------
        url : str
            URL of the original image
        animation_type : AnimationType
            Only "glint" is currently supported.
        """
        response = self._get_request('/v1/images/animate', {'url': url, 'type': animation_type}, stream=True)
        return Parser.image(response)

    @api_call
    def company_logo(self, domain, generateFallbackLogo=False):
        # type: (str, bool) -> str
        """
        Deprecated

        Returns a company logo based on website domain.
        If the logo is not in our database yet, it will be extracted from the site on the fly.
        White logo background is automatically removed to make the logo look better on color backgrounds.
        Note: It is not possible to access our company logo API publicly without authentication.
        If you wish to do so, you have to create a proxy on your own server that calls our API
        from the server side.

        Parameters
        ----------
        domain : str
            Hostname without http://
        generateFallbackLogo : bool
        """
        domain = self._sanitize_domain(domain)
        gen = 1 if generateFallbackLogo else 0
        response = self._get_request('/v2/company-insights/logo', {'domain': domain, 'generateFallbackLogo': gen})
        return Parser.company_logo(response.json())

    @api_call
    def company_logo_2(self, domain, generateFallbackLogo=False):
        # type: (str, bool) -> Logo
        """
        Returns a company logo based on website domain.
        If the logo is not in our database yet, it will be extracted from the site on the fly.
        White logo background is automatically removed to make the logo look better on color backgrounds.
        Note: It is not possible to access our company logo API publicly without authentication.
        If you wish to do so, you have to create a proxy on your own server that calls our API
        from the server side.

        Parameters
        ----------
        domain : str
            Hostname without http://
        generateFallbackLogo : bool
        """
        domain = self._sanitize_domain(domain)
        gen = 1 if generateFallbackLogo else 0
        response = self._get_request('/v2/company-insights/logo', {'domain': domain, 'generateFallbackLogo': gen})
        return Parser.company_logo_2(response.json())

    @api_call
    def list_of_cta(self):
        # type: () -> [Cta]
        """
        Returns list of available Link Ads for any given Rite.ly user.
        Requires each user to authenticate with RiteKit.
        """
        response = self._get_request('/v1/link/cta', {})
        return Parser.cta_list(response.json())

    @api_call
    def shorten_url(self, url, cta_id):
        # type: (str, int) -> Link
        """
        Returns a short link with a given Link Ad (a Rite.ly user's advertisements that are iFramed on URLs).

        Parameters
        ----------
        url : str
            URL to be shortened
        cta_id : int
            Link Ad ID returned by List of CTAs endpoint
        """
        url = self._sanitize_url(url)
        response = self._get_request('/v1/link/short-link', {'url': url, 'cta': cta_id})
        return Parser.link(response.json())

    def free_mail_detection(self, domain):
        # type: (str) -> bool
        """
        Returns true for a recognized free email address or domain.

        Filter out free personal emails (gmail.com, outlook.com) with freemail detection API; forward hot business
        leads to your sales team. Give special treatment only to those who register with business email addresses.
        Use this endpoint before calling Brand Colors and Company Logo so you spend credits on calls only for
        real leads.

        Parameters
        ----------
        domain : str
            domain or email address
        """
        domain = self._sanitize_domain(domain)
        response = self._get_request('/v2/person-insights/freemail-detection', {'domain': domain})
        return Parser.free_mail_detection(response.json())

    def disposable_email_detection(self, email):
        # type: (str) -> bool
        """
        Returns true for a recognized disposable email address

        Tired of free riders signing up with fake email addresses and using your app's free trial repeatedly?
        Stop wasting money for API calls, emails and other costs incurred by users who will never pay for anything.
        Prevent them from signing up with our Disposable Email Detection API.

        Parameters
        ----------
        email : str
            domain or email address
        """
        email = self._sanitize_domain(email)
        response = self._get_request('/v2/person-insights/disposable-email-detection', {'email': email})
        return Parser.disposable_email_detection(response.json())

    def email_typo(self, email):
        # type: (str) -> [str]
        """
        Returns an array of most likely corrected email domains.

        Users who make a typo in their email address never get your onboarding emails, cannot reset their password and
        cannot be even reached by your customer support. They are practically lost. With our Email Typo API you can
        check for typical mistakes in email addresses and show "Did you mean" suggestions right in your sign up form.

        Parameters
        ----------
        email : str
            domain or email address
        """
        email = self._sanitize_domain(email)
        response = self._get_request('/v2/person-insights/email-typo', {'email': email})
        return Parser.email_typo(response.json())

    def name_from_email_address(self, email):
        # type: (str) -> str
        """
        Returns name and surname derived from an email address.

        The less fields in a sign up form, the higher the completion rate. Asking for a real name of a user is seen as
        a nuisance serving no value for the user himself. However, using customer name in the UI or in the emails
        significantly improves conversion rates, open rates and even deliverability as it is an indication for spam
        filters that the email is probably personal. With Name from Email Address API, you can derive real names from
        email addresses without actually bothering users with filling unnecessary fields.

        Parameters
        ----------
        email : str
            domain or email address
        """
        email = self._sanitize_domain(email)
        response = self._get_request('/v2/person-insights/name-from-email-address', {'email': email})
        return Parser.name_from_email_address(response.json())

    def company_name_to_domain(self, name):
        # type: (str) -> [str]
        """
        Returns an array of most probable domains for a given company name.

        Use this API call to retrieve company domain that can be used in other RiteKit API calls, eg. Company Logo.

        Parameters
        ----------
        name : str
            company name
        """
        response = self._get_request('/v2/company-insights/name-to-domain', {'name': name})
        return response.json()['data']

    def brand_colors(self, domain):
        # type: (str) -> [str]
        """
        Returns array of brand colors for a given domain.

        Parameters
        ----------
        domain : str
            company name
        """
        domain = self._sanitize_domain(domain)
        response = self._get_request('/v2/company-insights/brand-colors', {'name': domain})
        return response.json()['data']

    def extract_hastags_for_url(self, url):
        # type: (str) -> [Hashtag]
        """
        Returns list of hashtag suggestions for any URL. Takes into account both semantic relevancy and
        real-time hashtag popularity.

        Parameters
        ----------
        url : str
            url
        """
        url = self._sanitize_url(url)
        response = self._get_request('/v2/stats/hashtags-for-url', {'url': url})
        return Parser.hashtag_list(response.json(), 'hashtags')

    def extract_article_for_url(self, url):
        # type: (str) -> ArticleForUrl
        """
        Returns a title and a text of an article extracted from a URL (ignoring text in headers, footers, columns etc.).
        Works in Arabic, Russian, Dutch, German, English, Spanish, French, Hebrew, Italian, Korean, Norwegian, Persian,
        Polish, Portuguese, Swedish, Hungarian, Finnish, Danish, Chinese, Indonesian, Vietnamese, Swahili, Turkish,
        Greek, Ukrainian.

        Parameters
        ----------
        url : str
            url
        """
        url = self._sanitize_url(url)
        response = self._get_request('/v2/text/extract-article', {'url': url})
        return Parser.article_for_url(response.json())

    def extract_top_image_for_url(self, url):
        # type: (str) -> str
        """
        Returns an image URL extracted from a page URL

        Parameters
        ----------
        url : str
            url
        """
        url = self._sanitize_url(url)
        response = self._get_request('/v2/image/extract-image', {'url': url})
        return response.json()['top_image']

    def on_limit(self, percentage, callback):
        # type: (int, callable) -> None
        self.callbacks.append(
            [percentage, callback]
        )



import os
import sys
import setuptools

from setuptools.command.test import test as TestCommand

cwd = os.path.abspath(os.path.dirname(__file__))
version_info = {}

with open(os.path.join(cwd, 'ritetag', '__version__.py'), 'r') as f:
    exec(f.read(), version_info)

with open("README.md", "r") as fh:
    long_description = fh.read()


class PyTest(TestCommand):
    user_options = [('pytest-args=', 'a', "Arguments to pass into py.test")]

    def initialize_options(self):
        TestCommand.initialize_options(self)
        self.pytest_args = []

    def finalize_options(self):
        TestCommand.finalize_options(self)
        self.test_args = []
        self.test_suite = True

    def run_tests(self):
        import pytest

        errno = pytest.main(self.pytest_args)
        sys.exit(errno)


if sys.argv[-1] == 'publish':
    os.system('rm -r dist/*')
    os.system('python setup.py sdist')
    os.system('twine upload dist/*')
    sys.exit()

setuptools.setup(
    name=version_info['__name__'],
    version=version_info['__version__'],
    author=version_info['__author__'],
    author_email=version_info['__email__'],
    description=version_info['__description__'],
    long_description=long_description,
    long_description_content_type="text/markdown",
    url=version_info['__url__'],
    packages=['ritetag'],
    tests_require=[
        'pytest'
    ],
    requires=[
        'requests'
    ],
    test_suite="tests",
    cmdclass={'test': PyTest},
    scripts=['bin/ritetag-api'],
    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    python_requires=">=2.7",
)
